@@ -22,9 +22,12 @@ use method syntax, viz:
    use PDL::Core '';
    use PDL::Ops '';
    use PDL::Primitive '';
+   use PDL::Ufunc '';
    use PDL::Basic '';
    use PDL::Slices '';
+   use PDL::Bad '';
    use PDL::Version;
+   use PDL::Lvalue;
 
 =cut
 
@@ -35,9 +38,12 @@ use method syntax, viz:
 use PDL::Core '';
 use PDL::Ops '';
 use PDL::Primitive '';
+use PDL::Ufunc '';
 use PDL::Basic '';
 use PDL::Slices '';
+use PDL::Bad '';
 use PDL::Version ;  # Doesn't export anything - no need for ''
+use PDL::Lvalue;
 
 $PDL::Lite::VERSION = $PDL::Version::VERSION;
 
